## What's Changed

- feat: implement the first version (b3cb5de)
- chore: add makefile for installation process (a8b2599)
- chore: add initial project configuration and server implementation (11e8273)
- chore: update license (fcff9ee)
- chore: update readme (28277d6)
- Initial commit (c799652)

**Full Changelog**: https://github.com/leynier/mcp-sys-bridge/commits/v0.1.0

